==> open-cluster-management-apps-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorschannel/apps/v1/ChannelGateFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface ChannelGateFluent<A extends ChannelGateFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> withNewLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public ChannelGateFluent.LabelSelectorNested<A> editLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<ChannelGateFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorschannel/apps/v1/ChannelGateFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorschannel.apps.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ChannelGateFluent<A extends ChannelGateFluent<A>> extends Fluent<A>{
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  
  /**
   * This method has been deprecated, please use method buildLabelSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getLabelSelector();
  public LabelSelector buildLabelSelector();
  public A withLabelSelector(LabelSelector labelSelector);
  public Boolean hasLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> withNewLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item);
  public ChannelGateFluent.LabelSelectorNested<A> editLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> editOrNewLabelSelector();
  public ChannelGateFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item);
  public String getName();
  public A withName(String name);
  public Boolean hasName();
  public interface LabelSelectorNested<N> extends Nested<N>,LabelSelectorFluent<ChannelGateFluent.LabelSelectorNested<N>>{
    public N and();
    public N endLabelSelector();
    
  }
  
}
